==> playfunads-2.0-sources.jar: playfun/ads/android/sdk/component/factory/popupfactory/PopUpAds.java <==
package playfun.ads.android.sdk.component.factory.popupfactory;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Fragment;
import android.app.FragmentTransaction;
import android.content.Context;
import android.util.AttributeSet;
import android.util.Log;

import playfun.ads.android.sdk.component.callback.AdsFunListener;
import playfun.ads.android.sdk.component.model.networkmodel.Data;
import playfun.ads.android.sdk.component.observer.AdsServices;
import playfun.ads.android.sdk.component.sate.FunAdsView;
import playfun.ads.android.sdk.component.util.AdsUtils;
import playfun.ads.android.sdk.component.util.PopUpEnum;

public class PopUpAds extends FunAdsView {

    private FragmentTransaction fragmentTransaction;
    private BasePopUp popUp;
    private Fragment fragment;

    private Data data;

    private Context context;

    private PopUpEnum popUpEnum;

    public PopUpAds(Context context,PopUpEnum popUpEnum) {
        super(context);
        System.out.printf(AdsUtils.TAG,"PopUpAds init : "+"PopUpAds");
        this.context = context;
        this.popUpEnum = popUpEnum;
    }

    public PopUpAds(Context context) {
        super(context);
        this.context = context;
    }

    public PopUpAds(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.context = context;
        initView();
    }

    public PopUpAds(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.context = context;
        initView();
    }

    @Override
    public void hideFunAds() {

    }

    @Override
    public void showFunAds() {
       initView();
    }

    @SuppressLint("LongLogTag")
    @Override
    public void loadFunAds() {
        Log.e(AdsUtils.TAG,"showFunAds: " + "popUpAds");

    }

    @SuppressLint("LongLogTag")
    private void initView() {
        if (context == null) {
            return;
        }
            Log.i(AdsUtils.TAG,"PopUpAds: " + "initView()");
        try {
            Activity activity = (Activity)context;
            fragmentTransaction = activity.getFragmentManager().beginTransaction();
            fragment = activity.getFragmentManager().findFragmentByTag("dialog");
            popUp = PopUpFactory.createPopUp(popUpEnum);
        } catch (Exception e) {
            System.out.println("can not cast context to Activity");
            e.printStackTrace();
        }
            if (fragment != null && fragment.isAdded()) {
                popUp.show(fragmentTransaction,"dialog");
                return;
            }
            try {
                fragmentTransaction.addToBackStack(null);
                popUp.show(fragmentTransaction,"dialog");
            } catch (Exception e) {
                System.out.println("Popup is null");
                e.printStackTrace();
            }

    }

    @Override
    public void updateAds(Data data) {
        super.updateAds(data);
        this.data = data;
    }

    @Override
    public void sendListener(AdsFunListener listener) {
        super.sendListener(listener);
        Log.e("adsView","updateAds_popup_ads");
        AdsServices adsServices = new AdsServices(data,listener);
        adsServices.attach(popUp);
        adsServices.notifyAllObserver();
    }
}

==> playfunads-3.0.1-sources.jar: playfun/ads/android/sdk/component/factory/popupfactory/PopUpAds.java <==
package playfun.ads.android.sdk.component.factory.popupfactory;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Fragment;
import android.app.FragmentTransaction;
import android.content.Context;
import android.util.AttributeSet;
import android.util.Log;

import playfun.ads.android.sdk.component.callback.AdsFunListener;
import playfun.ads.android.sdk.component.model.networkmodel.Data;
import playfun.ads.android.sdk.component.observer.AdsServices;
import playfun.ads.android.sdk.component.sate.FunAdsView;
import playfun.ads.android.sdk.component.util.AdsUtils;
import playfun.ads.android.sdk.component.util.PopUpEnum;

public class PopUpAds extends FunAdsView {

    private FragmentTransaction fragmentTransaction;
    private BasePopUp popUp;
    private Fragment fragment;

    private Data data;

    private Context context;

    private PopUpEnum popUpEnum;

    public PopUpAds(Context context,PopUpEnum popUpEnum) {
        super(context);
        System.out.printf(AdsUtils.TAG,"PopUpAds init : "+"PopUpAds");
        this.context = context;
        this.popUpEnum = popUpEnum;
    }

    public PopUpAds(Context context) {
        super(context);
        this.context = context;
    }

    public PopUpAds(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.context = context;
        initView();
    }

    public PopUpAds(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.context = context;
        initView();
    }

    @Override
    public void hideFunAds() {

    }

    @Override
    public void showFunAds() {
       initView();
    }

    @SuppressLint("LongLogTag")
    @Override
    public void loadFunAds(int inventoryId , String inventoryCode , int raaid) {
        Log.e(AdsUtils.TAG,"showFunAds: " + "popUpAds");

    }

    @SuppressLint("LongLogTag")
    private void initView() {
        if (context == null) {
            return;
        }
            Log.i(AdsUtils.TAG,"PopUpAds: " + "initView()");
        try {
            Activity activity = (Activity)context;
            fragmentTransaction = activity.getFragmentManager().beginTransaction();
            fragment = activity.getFragmentManager().findFragmentByTag("dialog");
            popUp = PopUpFactory.createPopUp(popUpEnum);
        } catch (Exception e) {
            System.out.println("can not cast context to Activity");
            e.printStackTrace();
        }
            if (fragment != null && fragment.isAdded()) {
                popUp.show(fragmentTransaction,"dialog");
                return;
            }
            try {
                fragmentTransaction.addToBackStack(null);
                popUp.show(fragmentTransaction,"dialog");
            } catch (Exception e) {
                System.out.println("Popup is null");
                e.printStackTrace();
            }

    }

    @Override
    public void updateAds(Data data) {
        super.updateAds(data);
        this.data = data;
    }

    @Override
    public void sendListener(AdsFunListener listener) {
        super.sendListener(listener);
        Log.e("adsView","updateAds_popup_ads");
        AdsServices adsServices = new AdsServices(data,listener);
        adsServices.attach(popUp);
        adsServices.notifyAllObserver();
    }
}
